library(Rmisc)
library(readr)
library(dplyr)
library(stringr)
library(ggplot2)
library(forcats)
library(tidyr)
library(RColorBrewer)
colorPalette <- "Set2"
myColors <- brewer.pal(8, colorPalette)
names(myColors) <- c("ORIGINAL", "DEFACE", "FACE MASK", "BLURRED", "QUICKSHEAR", "CP-GAN", "MRI WATERSHED", "BLACK")
colScaleManual <- scale_colour_manual(name = "Modality", values = myColors)
colScaleFill <- scale_fill_manual(name = "Modality", values = myColors)
dataset <- "OASIS-3"
base_size <- 50
theme_set(theme_light(base_size = base_size))
theme_update(text = element_text(size=base_size))
theme_update(axis.text = element_text(family = "TeX Gyre Pagella", color = "black"),
             panel.border = element_blank(),
             panel.spacing = unit(2, "lines"),
             strip.background=element_rect(fill="white"),
             strip.text = element_text(colour = 'black'),
             plot.title = element_text(hjust=0.5, margin = margin(0,0,0,0)),
             axis.ticks = element_blank(),
             axis.text.x = element_text(margin = margin(0, 0, 0, 0), angle=90, vjust=0.5, hjust=1, size=35),
             axis.text.y = element_text(margin = margin(0, 0, 0, 0)),
             plot.margin=grid::unit(c(5, 5, 0, if_else(dataset == "ADNI", 5, 5)), "mm"),
             legend.position=c(.77,.25),
             legend.title=element_blank(),
             legend.margin = margin(0, 10, 0, 0),
             legend.spacing.x = unit(0, "mm"),
             legend.spacing.y = unit(0, "mm"),
             legend.text=element_text(size=33, family = "TeX Gyre Pagella")
             )
dir.path <- str_c("/home/anonymized_user/Data", dataset, "ALGO_IDENT", sep = "/")
fnames <- Sys.glob(file.path(dir.path, "*.csv"))
canonical_order <- c("ORIGINAL", "DEFACE", "FACE MASK", "BLURRED", "QUICKSHEAR", "CP GAN", "MRI WATERSHED", "BLACK")
colorPalette <- "Set2"
tibbles <- vector(mode = "list", length = length(fnames))
splitId <- 1
for (fname in fnames) {
  data <- read_csv(fname) %>%
    mutate(Modality = str_to_upper(Modality)) %>%
    mutate(Modality = str_replace_all(Modality, "_", " ")) %>%
    mutate(Modality = str_replace_all(Modality, "-", " ")) %>%
    mutate(Modality = factor(Modality, levels = canonical_order)) %>%
    group_by(AnchorId) %>%
    mutate(Rank = Rank - 1) %>%
    mutate(PopulationSize = max(Rank)) %>%
    mutate(RelativeRank = Rank/PopulationSize)
  data.correct <- data %>%
    filter(CandidateScanId == CorrectScanId) %>%
    select(Modality, Rank, RelativeRank)
  mean.rank <- data.correct %>%
    group_by(Modality) %>%
    summarize(MeanRank = mean(Rank), MeanRelativeRank = mean(RelativeRank))
  within.rank <- vector(mode = "list", length = 100 + 1)
  for (k in seq(from=1, to=100 + 1)) {
    within.rank[[k]] <- data.correct %>%
      mutate(Withink = RelativeRank <= (k - 1)/100) %>%
      group_by(Modality) %>%
      summarize(ProbWithinRelativek = mean(Withink)) %>%
      mutate(`Relativek` = (k - 1)/100, SplitId = splitId)
  }
  tibbles[[splitId]] <- bind_rows(within.rank)
  splitId <- splitId + 1 
}
data <- bind_rows(tibbles) %>%
  nest(grp=c(SplitId, ProbWithinRelativek)) %>%
  mutate(ProbWithinRelativekCI = lapply(grp, function(df) CI(df$ProbWithinRelativek, ci=.95))) %>%
  select(-grp) %>%
  unnest_wider(ProbWithinRelativekCI, names_sep = "")
probPlot <- data %>%
  ggplot(aes(x=Relativek, y=ProbWithinRelativekCImean, color=Modality, fill = Modality)) +
  geom_line(size=2.0) +
  geom_ribbon(aes(ymin = ProbWithinRelativekCIlower, ymax = ProbWithinRelativekCIupper), alpha = 0.3, linetype = 0) + 
  scale_x_continuous(breaks = seq(from=if_else(dataset == "ADNI", 0, 0.1), to=1, by=.1), minor_breaks = seq(from=0, to=1, by=.1), expand=c(0, 0), limits = c(0, 1)) +
  scale_y_continuous(breaks = seq(from=0, to=1, by=.1), minor_breaks = seq(from=0, to=1, by=.1), expand=c(0, 0), limits = c(0, 1.025)) +
  xlab(NULL) +
  ylab(NULL) +
  colScaleManual +
  colScaleFill
if (dataset == "OASIS-3") 
{
  probPlot <- probPlot + theme(legend.position = "none")
} else {
  probPlot <- probPlot + theme(axis.text.y = element_blank(),
                               axis.ticks.y = element_blank(),
                               axis.ticks.length.y = unit(0, "pt"))
}
probPlot
ggsave(filename=str_c("/home/anonymized_user/anonymized_userAuthoring/ICCV21/figs/experiments/model_based/prob_curve_", dataset, ".png"), probPlot, width=10, height=10)
