library(readr)
library(dplyr)
library(stringr)
library(ggplot2)
library(forcats)
library(tidyr)
oasis3_regex <- "(OAS[0-9]+)"
adni_regex <- "ADNI_([0-9]{3}_S_[0-9]{4})"
dataset <- "OASIS-3"
num_reps <- 100
regex <- if_else(dataset == "OASIS-3", oasis3_regex, adni_regex)
example_axis.fname <- str_c("/home/anonymized_user/remote/anonymized_server/home/anonymized_user/Data/", dataset, "/ALGO_IDENT/example_axis.dat")
data<- tibble(FullExampleId=read_lines(example_axis.fname)) %>%
  separate(FullExampleId, sep="~", into=c("Modality", "ExampleId"), remove = FALSE) %>%
  mutate(SubjectId=str_extract(ExampleId, regex)) %>%
  mutate(Modality=factor(Modality), SubjectId=factor(SubjectId)) %>%
  select(-Modality, -ExampleId)
subject.ids.distinct <- data %>%
  select(SubjectId) %>%
  distinct()
for (i in 1:num_reps) {
  subject.ids.train <- subject.ids.distinct %>%
    sample_frac(size=.8) %>%
    pull(SubjectId)
  subject.ids.test <- subject.ids.distinct %>%
    filter(!(SubjectId %in% subject.ids.train)) %>%
    pull(SubjectId)
  data.split <- data %>%
    mutate(InTrainSet=if_else(SubjectId %in% subject.ids.train, "TRAIN", "TEST")) %>%
    group_split(InTrainSet)
  data.train <- data.split[[2]]
  data.test <- data.split[[1]]
  example.ids.train <- data.train %>% pull(FullExampleId)
  example.ids.test <- data.test %>% pull(FullExampleId)
  write_lines(example.ids.train, str_c("/home/anonymized_user/remote/anonymized_server/home/anonymized_user/Data/", dataset, str_c("/ALGO_IDENT/example_train_ids_", i, ".dat")))
  write_lines(example.ids.test, str_c("/home/anonymized_user/remote/anonymized_server/home/anonymized_user/Data/", dataset, str_c("/ALGO_IDENT/example_test_ids_", i, ".dat")))
}
