from argparse import ArgumentParser
import pathlib
import re
import numpy as np
import h5py
from tqdm import tqdm
from skimage.io import imread
from skimage.transform import resize
extract_oasis3_subject = re.compile(r"(OAS[0-9]+)")
extract_adni_subject = re.compile(r"ADNI_([0-9]{3}_S_[0-9]{4})")
def main():
    parser = ArgumentParser()
    parser.add_argument("--data_dir",
                        help="Where the modalities resides",
                        required=True)
    parser.add_argument("--dataset",
                        help="Either OASIS-3 or ADNI",
                        choices=("OASIS-3", "ADNI"),
                        required=True)
    parser.add_argument("--modalities",
                        help="From which modalities the images are extracted",
                        default=["original", "cp-gan", "deface", "blurred", "black",
                                 "mri_watershed", "quickshear", "face_mask"])
    args = parser.parse_args()
    args.data_dir = pathlib.Path(args.data_dir).joinpath(args.dataset)
    args.renderings_dir = args.data_dir.joinpath("user_study_nuevo", "renderings")
    extract_subject = (extract_oasis3_subject, extract_adni_subject)[args.dataset == "ADNI"]
    args.output_dir = args.data_dir.joinpath("ALGO_IDENT")
    assert args.data_dir.exists(), "Data directory does not exist!"
    assert args.renderings_dir.exists(), "Renderings directory does not exist!"
    args.output_dir.mkdir(exist_ok=True)
    example_dirs = [example_dir for example_dir in args.renderings_dir.glob("*") if example_dir.is_dir()]
    subject_ids = sorted({extract_subject.search(scan_dir.stem).group() for scan_dir in example_dirs})
    with open(args.output_dir.joinpath("subject_axis.dat"), "w") as f:
        for subject_id in subject_ids:
            f.write(subject_id + "\n")
    with open(args.output_dir.joinpath("modality_axis.dat"), "w") as f:
        for modality in args.modalities:
            f.write(modality + "\n")
    output_fname = args.output_dir.joinpath(f"MRI_Ident.h5")
    with h5py.File(output_fname, "w") as fhandle, open(args.output_dir.joinpath("example_axis.dat"), "w") as f_example:
        fhandle.create_group("original")
        for example_dir in tqdm(example_dirs):
            for modality in args.modalities:
                img_fname = example_dir.joinpath(f"{modality}.png")
                img = imread(img_fname)
                img = resize(img, output_shape=(128, 128))
                fhandle["original"].create_dataset(name=f"{modality}~{example_dir.stem}",
                                                   shape=(128, 128, 3),
                                                   dtype=np.float32,
                                                   data=img)
                f_example.write(f"{modality}~{example_dir.stem}\n")
if __name__ == "__main__":
    main()
