library(readr)
library(ggplot2)
library(tidyr)
library(dplyr)
library(stringr)
library(forcats)
library(kableExtra)
base_size <- 40
theme_set(theme_light(base_size = base_size))
theme_update(text = element_text(size=base_size))
theme_update(panel.grid.major.x = element_blank(),
             axis.text.x = element_text(family = "TeX Gyre Pagella", angle = 45, vjust = 1.0, hjust=1, color = "black"),
             panel.border = element_blank(),
             axis.ticks.y  = element_blank(),
             plot.title = element_text(hjust = 0.5),
             axis.ticks.x = element_line(color = "black"))
canonical_order <- str_to_upper(c("original", "blurred", "face mask", "deface", "quickshear", "mri watershed", "cp-gan", "black"))
raw_data <- NULL
for (dataset in c("ADNI", "OASIS-3"))
{
results.fname <- str_c("/home/anonymized_user/remote/anonymized_server/home/anonymized_user/Data/", dataset, "/ALGO_IDENT/all_results.csv")
data <- read_csv(results.fname) %>%
  pivot_longer(cols=everything(), names_to="Modality", values_to="IdentificationRate") %>%
  mutate(Modality=str_replace(Modality, "_", " ")) %>%
  mutate(Modality=factor(str_to_upper(Modality), levels = canonical_order)))
data %>%
  ggplot(aes(x=Modality, y=IdentificationRate)) +
  geom_boxplot(show.legend = FALSE, outlier.shape = NA, fatten = NULL, color = "lightslategray") +
  geom_boxplot(aes(color=Modality),
               fatten = NULL, fill = NA, coef = 0, outlier.shape = NA, 
               show.legend = F) +
  stat_summary(geom = "crossbar", width=0.65, fatten=0, color="lightslategray", show.legend = F, 
               fun.data = function(x){c(y=median(x), ymin=median(x), ymax=median(x))}) +
  xlab(NULL) +
  ylab(NULL) +
  ylim(c(0, 100)) +
  scale_y_continuous(breaks=c(0,20,40,60,80, 100)) +
  ggtitle(dataset)
data.stat <- data %>%
  group_by(Modality) %>%
  summarize(IdentificationRateSD=sd(IdentificationRate),
            IdentificationRateMean=mean(IdentificationRate)) %>%
  mutate(IdentificationRate = str_c(round(IdentificationRateMean, digits = 2), "±", round(IdentificationRateSD, digits = 2))) %>%
  mutate(Dataset=dataset) %>%
  select(Dataset, Modality, IdentificationRate)
  if (is.null(raw_data)) {
    raw_data <- data.stat
  } else {
    raw_data <- bind_rows(raw_data, data.stat)
  }
}
raw_data <- raw_data %>%
  pivot_wider(names_from = Dataset, values_from = IdentificationRate)
header_row <- c("Method", 'OASIS-3', "ADNI")
latex_table <- raw_data %>%
  kable(format = "latex", booktabs = T, row.names = F, col.names = c(), linesep = "", align = c("l", rep("c", length(header_row) - 1))) %>%
  add_header_above(header_row, monospace = T) %>%
  column_spec(1, bold = T)
latex_table
