import torch
import torch.nn as nn
class ResNet3D(nn.Module):
    def __init__(self,
                 num_layers: int,
                 num_channels: int,
                 kernel_size: int):
        super().__init__()
        assert num_layers > 0, "Number of layers has to be non-negative!"
        assert num_channels > 0, "Number of channels has to be non-negative!"
        assert kernel_size % 2 == 1, "Kernel size has to be odd!"
        self.num_layers = num_layers
        self.num_channels = num_channels
        self.kernel_size = kernel_size
        padding = (kernel_size - 1) // 2
        self.init_cnn = nn.Conv3d(in_channels=1,
                                  out_channels=num_channels,
                                  kernel_size=kernel_size,
                                  padding=padding)
        self.cnn = nn.ModuleList(nn.Conv3d(in_channels=num_channels,
                                           out_channels=num_channels,
                                           kernel_size=kernel_size,
                                           padding=padding) for _ in range(num_layers))
        self.post_cnn = nn.Conv3d(in_channels=num_channels,
                                  out_channels=1,
                                  kernel_size=kernel_size,
                                  padding=padding)
    @staticmethod
    def swish(x):
        return x * torch.sigmoid(x)
    def forward(self, x):
        x = self.init_cnn(x)
        for cnn_layer in self.cnn:
            x = x + self.swish(cnn_layer(x))
        x = torch.sigmoid(self.post_cnn(x))
        return x
