import torch
import torch.nn as nn
class UNet3D(nn.Module):
    def __init__(self,
                 num_layers: int,
                 branch_factor: int,
                 kernel_size: int):
        super().__init__()
        assert num_layers > 0, "Number of layers has to be non-negative!"
        assert branch_factor > 0, "Branch factor has to be greater than 0!"
        assert kernel_size % 2 == 1, "Kernel size has to be odd!"
        self.num_layers = num_layers
        self.branch_factor = branch_factor
        self.kernel_size = kernel_size
        same_padding = (kernel_size - 1) // 2
        padding = 0
        self.encoder = nn.ModuleList(nn.Conv3d(in_channels=branch_factor**i,
                                               out_channels=branch_factor**(i + 1),
                                               kernel_size=kernel_size,
                                               stride=branch_factor,
                                               padding=padding) for i in range(num_layers))
        self.center = nn.ModuleList(nn.Conv3d(in_channels=branch_factor**num_layers ,
                                              out_channels=branch_factor**num_layers,
                                              kernel_size=kernel_size,
                                              padding=same_padding) for _ in range(num_layers))
        self.decoder = nn.ModuleList(nn.ConvTranspose3d(in_channels=branch_factor**num_layers if i == num_layers - 1 else 2 * branch_factor**(i + 1),
                                                        out_channels=branch_factor**i,
                                                        kernel_size=kernel_size,
                                                        stride=branch_factor,
                                                        padding=padding) for i in reversed(range(num_layers)))
        print()
    @staticmethod
    def swish(x):
        return x * x.sigmoid()
    def forward(self, x):
        encoder_intermediate = []
        for encoder_layer in self.encoder:
            encoder_intermediate.append(x)
            x = self.swish(encoder_layer(x))
        for center_layer in self.center:
            x = self.swish(center_layer(x))
        i = 0
        for encoder_features, decoder_layer in zip(reversed(encoder_intermediate), self.decoder):
            x = decoder_layer(x, output_size=encoder_features.shape)
            x = x if i == self.num_layers - 1 else torch.cat([self.swish(x), encoder_features], dim=1)
            i += 1
        return x
