import torch
import torch.nn as nn
class VanillaConv3D(nn.Module):
    def __init__(self,
                 branch_factor: int,
                 num_layers: int,
                 kernel_size: int):
        super().__init__()
        assert branch_factor > 0, "Branch factor has to be greater than 0!"
        assert num_layers > 0, "Number of layers has to be non-negative!"
        assert kernel_size % 2 == 1, "Kernel size has to be odd!"
        self.branch_factor = branch_factor
        self.num_layers = num_layers
        self.kernel_size = kernel_size
        self.cnn = nn.ModuleList(nn.Conv3d(in_channels=branch_factor**layer_id,
                                           out_channels=branch_factor**(layer_id + 1),
                                           kernel_size=kernel_size,
                                           padding=0) for layer_id in range(num_layers))
    @staticmethod
    def swish(x):
        return x * torch.sigmoid(x)
    def forward(self, x):
        for cnn_layer in self.cnn:
            x = self.swish(cnn_layer(x))
        return x
