from argparse import ArgumentParser
import pathlib
import pandas as pd
import re
import yaml
extract_data = re.compile(r"ADNI_([0-9]{3}_S_[0-9]{4}).*_I([0-9]{5,6})")
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_fname",
                        help="The ADNI CSV file that contains the metadata",
                        required=True)
    parser.add_argument("--input_dir",
                        help="Where the ADNI files reside",
                        required=True)
    parser.add_argument("--output_dir",
                        help="Where the CSV containing the ages is stored",
                        required=True)
    args = parser.parse_args()
    args.input_fname = pathlib.Path(args.input_fname)
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    data = pd.read_csv(args.input_fname)
    data['Subject'] = data['Subject'].astype(str)
    data['Image Data ID'] = data['Image Data ID'].astype(str)
    data['Full ID'] = data['Subject'] + "__" + data['Image Data ID']
    age_dict = dict(data[['Full ID', 'Age']].values.tolist())
    alzheimer_dict = dict(data[['Full ID', 'Group']].values.tolist())
    metadata_age, metadata_alzheimer = {}, {}
    for fname in args.input_dir.glob("*.npy.tar.xz"):
        full_id = "__".join(extract_data.findall(fname.stem)[0])
        metadata_age[fname.stem] = age_dict[full_id]
        metadata_alzheimer[fname.stem] = alzheimer_dict[full_id]
    pd.Series(metadata_age).to_csv(args.output_dir.joinpath("metadata_age.csv"))
    pd.Series(metadata_alzheimer).to_csv(args.output_dir.joinpath("metadata_alzheimer.csv"))
if __name__ == "__main__":
    main()
