from argparse import ArgumentParser
import pathlib
import pandas as pd
import re
from collections import defaultdict
from utils import get_real_stem
extract_data = re.compile(r"IXI([0-9]{3})-[a-zA-Z]+-([0-9]{4})")
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_fname",
                        help="The ADNI CSV file that contains the metadata",
                        required=True)
    parser.add_argument("--input_dir",
                        help="Where the ADNI files reside",
                        required=True)
    parser.add_argument("--output_dir",
                        help="Where the CSV containing the ages is stored",
                        required=True)
    args = parser.parse_args()
    args.input_fname = pathlib.Path(args.input_fname)
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    data = pd.read_excel(args.input_fname)
    data['IXI_ID'] = data['IXI_ID'].astype(str)
    age_dict = defaultdict(lambda: float('nan'), data[['IXI_ID', 'AGE']].values.tolist())
    metadata = {}
    for fname in args.input_dir.glob("*.nii.gz"):
        first_id, second_id = extract_data.findall(get_real_stem(fname))[0]
        first_id = first_id.lstrip('0')
        metadata[fname.stem] = age_dict[first_id]
    pd.Series(metadata).to_csv(args.output_dir.joinpath("metadata.csv"))
if __name__ == "__main__":
    main()
