from argparse import ArgumentParser
import pathlib
import xnat
import pandas as pd
from collections import defaultdict
from tqdm import tqdm
from utils import get_real_stem
def main():
    parser = ArgumentParser()
    parser.add_argument("--output",
                        required=True)
    args = parser.parse_args()
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    assert args.nifti_dir.exists(), "Input directory does not exist!"
    age_dict = defaultdict(int)
    with xnat.connect('https://central.xnat.org', user="lennart.vandergoten") as session:
        oasis_project = session.projects["OASIS3"]
        for subject in tqdm(oasis_project.subjects.values()):
            experiments = subject.experiments
            for experiment in experiments.values():
                if isinstance(experiment, session.classes.MrSessionData):
                    for scan_id in experiment.scans:
                        scan_type = experiment.scans[scan_id].type
                        if "T1w" in scan_type and experiment.field_strength == "3":
                            label = f"{experiment.label}_{scan_id}"
                            files = experiment.scans[scan_id].files
                            for file in files.listing:
                                if ".nii.gz" in file.id:
                                    age_dict[file.id.split(".nii.gz")[0]] = experiment.age
        pd.Series(age_dict).to_csv(args.output)
if __name__ == "__main__":
    main()
