import pathlib
from argparse import ArgumentParser
import ants
from joblib import delayed, Parallel
from tqdm import tqdm
def ants_registration(input_fname: pathlib.Path,
                      fixed_fname: pathlib.Path,
                      output_fname: pathlib.Path) -> None:
    ants_input_img = ants.image_read(filename=str(input_fname), reorient=False)
    ants_fixed_img = ants.image_read(filename=str(fixed_fname), reorient=False)
    """
    Output:
        - 'warpedmovout': Moving image warped to space of fixed image.
        - 'warpedfixout': Fixed image warped to space of moving image.
        - 'fwdtransforms': Transforms to move from moving to fixed image.
        - 'invtransforms': Transforms to move from fixed to moving image.
    """
    registration = ants.registration(fixed=ants_fixed_img,
                                     moving=ants_input_img,
                                     type_of_transform="TRSAA")
    ants.image_write(image=registration['warpedmovout'], filename=str(output_fname))
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="Where the NifTi files reside",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = args.input_dir.parent.joinpath(f"{args.input_dir.name}_ANTs")
    args.output_dir.mkdir(exist_ok=True)
    args.input_dir.exists(), "Input directory does not exist!"
    input_fnames = [input_fname for input_fname in args.input_dir.glob("*.nii.gz")]
    output_fnames = [args.output_dir.joinpath('ants' + input_fname.name) for input_fname in input_fnames ]
    fixed_fname = input_fnames.pop()
    Parallel(n_jobs=args.num_jobs)(delayed(ants_registration)(input_fname=input_fname,
                                                              fixed_fname=fixed_fname,
                                                              output_fname=output_fname) for input_fname, output_fname in tqdm(zip(input_fnames, output_fnames)))
if __name__ == "__main__":
    main()
