from argparse import ArgumentParser
import pathlib
from tqdm import tqdm
import numpy as np
from joblib import Parallel, delayed
import nibabel as nib
import yaml
def convert2nifti(fname: pathlib.Path):
    output_fname = str(fname.with_suffix(".nii.gz"))
    arr = np.load(fname)
    img = nib.Nifti1Image(arr, affine=np.eye(4))
    nib.save(img, output_fname)
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="Where the -compressed- ndarrays are located",
                        required=True)
    parser.add_argument("--zscore_fname",
                        help="Where the means and stddevs of the normalization are stored",
                        required=True)
    parser.add_argument("--output_dir",
                        help="Where the NifTi files will be stored",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=10)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    args.input_dir.exists(), "Input directory does not exist!"
    args.zscore_fname.exists(), "Z-Score statistics do not exist!"
    input_fnames = [fname for fname in args.input_dir.glob("*.npz")]
    with open(args.zscore_fname) as f:
        zscore_stats = yaml.load(f, Loader=yaml.FullLoader)
    Parallel(n_jobs=args.num_jobs)(delayed(convert2nifti)(fname=input_fname) for input_fname in tqdm(input_fnames))
if __name__ == "__main__":
    main()
