import os
from argparse import ArgumentParser
import pathlib
import subprocess
import shlex
from joblib import delayed, Parallel
from tqdm import tqdm
from utils import get_real_stem
""" Executables """
HOME_DIR = os.path.join(os.path.expanduser("~"))
os.environ["PATH"] += os.pathsep + os.pathsep.join([os.path.join(HOME_DIR, "Build/dpat-tools/LIBRARY/"),
                                                    os.path.join(HOME_DIR, "FSL/bin/")])
os.environ["FSLWISH"] = os.path.join(HOME_DIR, "FSL/bin/fslwish")
os.environ["FSLDIR"] = os.path.join(HOME_DIR, "FSL")
os.environ["FSLMACHINELIST"] = ""
os.environ["FSLTCLSH"] = os.path.join(HOME_DIR, "FSL/bin/fsltclsh")
os.environ["FSLREMOTECALL"] = ""
os.environ["FSLLOCKDIR"] = ""
os.environ["FSLGECUDAQ"] = "cuda.q"
os.environ["FSLOUTPUTTYPE"] = "NIFTI_GZ"
os.environ["FSLMULTIFILEQUIT"] = "TRUE"
def convert_to_analyze(nifti_fname: pathlib.Path, output_dir: pathlib.Path):
    output_stem = output_dir.joinpath(get_real_stem(nifti_fname))
    output_hdr_fname = output_stem.with_suffix(".hdr")
    output_img_fname = output_stem.with_suffix(".img")
    if output_hdr_fname.exists() or output_img_fname.exists():
        print(f"{output_stem} exists already! Skipping")
        return
    subprocess.check_output(shlex.split(f"fslchfiletype ANALYZE {nifti_fname} {output_stem}"))
def main():
    parser = ArgumentParser()
    parser.add_argument("--nifti_dir",
                        help="Where the NifTi files reside",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    args = parser.parse_args()
    output_dir = pathlib.Path(args.nifti_dir.replace("NIFTI", "ANALYZE"))
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    output_dir.mkdir(exist_ok=True)
    args.nifti_dir.exists(), "NifTi directory does not exist!"
    Parallel(n_jobs=args.num_jobs)(delayed(convert_to_analyze)(nifti_fname=nifti_fname,
                                                               output_dir=output_dir) for nifti_fname in
                                   tqdm(args.nifti_dir.glob("*.nii.gz")))
if __name__ == "__main__":
    main()
