import os
import pathlib
from argparse import ArgumentParser
from glob import glob
import nibabel as nib
import h5py
from tqdm import tqdm
import numpy as np
from utils import get_real_stem
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="Directory containing the NifTi files",
                        required=True)
    parser.add_argument("--group",
                        help="HDF5 group",
                        default="original")
    parser.add_argument("--output_dir",
                        help="Directory to save hdf5 files",
                        default=None)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    if args.output_dir:
        args.output_dir = pathlib.Path(args.output_dir)
    else:
        args.output_dir = args.input_dir
    print(args.input_dir)
    assert args.input_dir.exists(), "Input directory does not exist!"
    input_fnames = list(args.input_dir.glob("*.nii.gz"))
    assert input_fnames, "There are no NifTi files in the input directory!"
    output_fname = args.output_dir.joinpath(f"{args.input_dir.name}.h5")
    print(output_fname)
    with h5py.File(output_fname, "w") as f:
        gr = f.require_group(name=args.group)
        for fname in tqdm(input_fnames):
            img_id = get_real_stem(fname) 
            img = nib.load(fname)
            img_arr = img.get_fdata(dtype=np.float32)
            gr.create_dataset(name=img_id, data=img_arr)
if __name__ == "__main__":
    main()
