from argparse import ArgumentParser
import pathlib
import re
from operator import itemgetter
import itertools
from sklearn.model_selection import train_test_split
extract_oasis3_attrs = re.compile(r"(OAS[0-9]+)")
extract_adni_attrs = re.compile(r"ADNI_([0-9]{3}_S_[0-9]{4})")
def get_real_stem(fname: pathlib.Path):
    return fname.name.split(".")[0]
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="A folder containing .npz files",
                        required=True)
    parser.add_argument("--dataset",
                        help="Which dataset should be partitioned",
                        choices=("IXI", "OASIS-3", "ADNI"),
                        required=True)
    parser.add_argument("--train_test_ratio",
                        default=.8)
    parser.add_argument("--output_dir",
                        help="Where to store the split specifications",
                        required=True)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    assert args.input_dir.exists(), "Input directory does not exist!"
    assert args.output_dir.exists(), "Output directory does not exist!"
    if args.dataset == "IXI":
        example_ids = [get_real_stem(fname) for fname in args.input_dir.glob("*.npy.tar.xz")]
        train_ids, test_ids = train_test_split(example_ids, train_size=args.train_test_ratio)
    elif args.dataset in ("OASIS-3", "ADNI"):
        regex = [extract_adni_attrs, extract_oasis3_attrs][args.dataset == "OASIS-3"]
        subject_ids = [(get_real_stem(fname), regex.search(get_real_stem(fname)).group()) for fname in args.input_dir.glob("*.npy.tar.xz")]
        subject_ids.sort(key=itemgetter(1))
        subject_id_to_fname = {subject_id: list(map(itemgetter(0), fnames)) for subject_id, fnames in itertools.groupby(subject_ids, key=itemgetter(1))}
        train_subject_ids, test_subject_ids = train_test_split(list(subject_id_to_fname.keys()), train_size=args.train_test_ratio)
        train_ids = list(itertools.chain(*[subject_id_to_fname[train_subject_id] for train_subject_id in train_subject_ids]))
        test_ids = list(itertools.chain(*[subject_id_to_fname[test_subject_id] for test_subject_id in test_subject_ids]))
    else:
        raise SystemError()
    args.output_dir.joinpath("train.dat").write_text("\n".join(train_ids))
    args.output_dir.joinpath("test.dat").write_text("\n".join(test_ids))
if __name__ == "__main__":
    main()
