from argparse import ArgumentParser
import pathlib
import shutil
from joblib import Parallel, delayed
from tqdm import tqdm
import nibabel as nib
def load_correct_save(fname: pathlib.Path, output_dir: pathlib.Path):
    subject_id, run_id, _, _ = fname.parts[-4:]
    img = nib.load(str(fname))
    img.header.set_qform(img.affine, 1)
    nib.save(img, str(output_dir.joinpath(f"{subject_id}_{run_id}.nii.gz")))
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="The root directory that should be flattened",
                        required=True)
    parser.add_argument("--output_dir",
                        help="Where the output files should be stored",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=20)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    args.input_dir.exists(), "Input directory does not exist!"
    args.output_dir.mkdir(exist_ok=True)
    Parallel(n_jobs=args.num_jobs)(delayed(load_correct_save)(fname=fname,
                                                              output_dir=args.output_dir) for fname in
                                   tqdm(args.input_dir.glob("**/*.nii.gz")))
if __name__ == "__main__":
    main()
