DATA_NAME="IXI"
CODE_PATH="$HOME/Code"
DATA_PATH="$HOME/Data/$DATA_NAME"
TEMPLATE_PATH="$CODE_PATH/nii_templates"
COMPRESS_NDARRAYS="--compress_ndarrays"   
REGISTRATION="--registration"  
NUM_JOBS=15
RESOLUTION=128
export PYTHONPATH=$CODE_PATH
set -e
NIFTI_TEMPLATE_PATH=""
case $DATA_NAME in
  "IXI")
    NIFTI_TEMPLATE_PATH="$TEMPLATE_PATH/Template_IXI_IXI280.nii.gz"
  ;;
  "OASIS-3")
    NIFTI_TEMPLATE_PATH="$TEMPLATE_PATH/Template_OASIS_OAS30003_ses-d1631_run-02_T1w.nii.gz"
  ;;
  "ADNI")
    NIFTI_TEMPLATE_PATH="$TEMPLATE_PATH/Template_ADNI_002_S_0295_20070319113623975_S13408_I45108.nii.gz"
  ;;
esac
mkdir -p $DATA_PATH
cp "$(readlink -f $0)" "$DATA_PATH/preprocess_datasets.sh"
echo "Preprocessing ${DATA_NAME}..."
 case $DATA_NAME in
   "IXI")
     wget --no-clobber http://biomedic.doc.ic.ac.uk/brain-development/downloads/IXI/IXI-T1.tar
     mkdir -p $DATA_PATH
     tar -xf IXI-T1.tar
     mkdir -p $DATA_PATH/${DATA_NAME}_NIFTI
     mv *.nii.gz $DATA_PATH/${DATA_NAME}_NIFTI
   ;;
   "OASIS-3")
     mkdir -p $DATA_PATH
     python $CODE_PATH/conversion/download_oasis3.py --output_dir $DATA_PATH/${DATA_NAME}_NIFTI
   ;;
   "ADNI")
     unzip $DATA_PATH/\*.zip -d $DATA_PATH;
     python ${CODE_PATH}/conversion/flatten_adni.py --input_dir $DATA_PATH/${DATA_NAME} --output_dir $DATA_PATH/${DATA_NAME}_NIFTI;
   ;;
 esac
python $CODE_PATH/conversion/preprocess_mri.py --input_dir $DATA_PATH/${DATA_NAME}_NIFTI --output_dir $DATA_PATH/${DATA_NAME}_NIFTI_P --dataset $DATA_NAME --template $NIFTI_TEMPLATE_PATH --num_jobs $NUM_JOBS $REGISTRATION;
python $CODE_PATH/trimming/trim_to_bounding_box.py --input_dir $DATA_PATH/${DATA_NAME}_NIFTI_P --output_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT --num_jobs $NUM_JOBS;
python $CODE_PATH/skull_stripping/skull_strip.py --input_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT --output_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT_Robex --method Robex --num_jobs $NUM_JOBS;
python $CODE_PATH/conversion/convert_to_ndarrays.py --input_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT_Robex --output_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PT_Robex --num_jobs $NUM_JOBS $COMPRESS_NDARRAYS;
python $CODE_PATH/normalization/normalize.py --input_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT --brain_dir $DATA_PATH/${DATA_NAME}_NIFTI_PT_Robex --output_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTN --num_jobs $NUM_JOBS $COMPRESS_NDARRAYS;
python $CODE_PATH/anonymization/surface_extraction.py --input_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTN --output_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTNF --num_jobs $NUM_JOBS $COMPRESS_NDARRAYS;
python $CODE_PATH/anonymization/create_paired_dataset.py --input_original_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTN --input_face_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTNF --input_brain_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PT_Robex --output_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTN_PTNF_PT_Robex_Paired --num_jobs $NUM_JOBS;
python $CODE_PATH/anonymization/prepare_dl_dataset.py --paired_dataset $DATA_PATH/${DATA_NAME}_NDARRAY_PTN_PTNF_PT_Robex_Paired --output_dir $DATA_PATH/${DATA_NAME}_HDF5_PTN_PTNF_PT_Robex_Paired_DL;
python $CODE_PATH/conversion/create_data_split.py --input_dir $DATA_PATH/${DATA_NAME}_NDARRAY_PTN_PTNF_PT_Robex_Paired --dataset $DATA_NAME --output_dir $DATA_PATH
