import pathlib
from torch.utils.data import Dataset as AbstractDataset
import numpy as np
import nibabel as nib

class Dataset(AbstractDataset):
    def __init__(self,
                 data_dir: pathlib.Path,
                 index_fname: pathlib.Path,
                 age_fname: pathlib.Path):
        super().__init__()

        self.data_dir = data_dir
        self.index_fname = index_fname
        self.age_fname = age_fname

        self.example_ids = self.index_fname.read_text().strip().split("\n")
        self.subject_to_age = dict()
        for line in self.age_fname.read_text().strip().split("\n"):
            subject_id, age = line.split(",")
            self.subject_to_age[subject_id] = float(age)

    def __len__(self):
        return len(self.example_ids)

    def __getitem__(self, i):
        example_id = self.example_ids[i]
        subject_age = self.subject_to_age[example_id]

        img = nib.load(self.data_dir.joinpath(f"{example_id}.nii.gz"))
        arr = img.get_fdata(dtype=np.float32)
        arr = (arr - np.mean(arr))/np.std(arr)

        return {"example_id": example_id,
                "arr": arr[np.newaxis, ...],
                "age": subject_age}