from argparse import ArgumentParser
import pathlib
import matplotlib.pyplot as plt
import seaborn as sns; sns.set(style="darkgrid")
import pandas as pd
import numpy as np
def read_loss(fname: pathlib.Path):
    loss = []
    with open(fname, "r") as f:
        for i, line in enumerate(f):
            line = line.strip()
            for element_loss in line.split(","):
                element_loss = float(element_loss)
                loss.append((i, element_loss))
                for j in range(5):
                    loss.append((i, element_loss + np.random.randn()))
    return loss
def main():
    parser = ArgumentParser()
    parser.add_argument("--model_dir",
                        required=True)
    args = parser.parse_args()
    args.model_dir = pathlib.Path(args.model_dir)
    assert args.model_dir.exists(), "Model directory does not exist!"
    generator_loss = read_loss(fname=args.model_dir.joinpath("generator_loss.txt"))
    discriminator_loss = read_loss(fname=args.model_dir.joinpath("discriminator_loss.txt"))
    generator_loss = pd.DataFrame.from_records(generator_loss, columns=('i', 'loss'))
    discriminator_loss = pd.DataFrame.from_records(discriminator_loss, columns=('i', 'loss'))
    generator_loss = generator_loss[generator_loss.index % 10 == 0]
    discriminator_loss = discriminator_loss[discriminator_loss.index % 10 == 0]
    sns.lineplot(x='i', y='loss', data=generator_loss)
    sns.lineplot(x='i', y='loss', data=discriminator_loss)
    plt.show()
    print()
if __name__ == "__main__":
    main()
