from argparse import ArgumentParser
import pathlib
import skull_stripping
from joblib import delayed, Parallel
from tqdm import tqdm
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="Where the original NifTi files reside",
                        required=True)
    parser.add_argument("--output_dir",
                        help="Where the NifTi files will be stored",
                        required=True)
    parser.add_argument("--method",
                        help="Which method to use",
                        choices=["FreesurferWatershed", "Robex"])
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    args.output_dir.mkdir(exist_ok=True)
    method = getattr(skull_stripping, args.method)()
    assert args.input_dir.exists(), "Input directory does not exist!"
    input_fnames = list(args.input_dir.glob("*.nii.gz"))
    output_fnames = [args.output_dir.joinpath(input_fname.name) for input_fname in input_fnames]
    Parallel(n_jobs=args.num_jobs)(delayed(method.strip_skull)(input_fname,
                                                               output_fname) for input_fname, output_fname in tqdm(zip(input_fnames, output_fnames)))
if __name__ == "__main__":
    main()
