import sys
from argparse import ArgumentParser
import pathlib
import tempfile
import random
import subprocess
import shlex
from time import perf_counter, sleep
from utils import get_real_stem
PYTHON_PATH = sys.executable
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="The NifTi directory containing the preprocessed files",
                        required=True)
    parser.add_argument("--mask_dir",
                        help="The NifTi directory containing the masks",
                        required=True)
    parser.add_argument("--methods",
                        nargs="+",
                        default=('deface', 'face_mask', 'quickshear', 'mri_watershed', 'msggan'))
    parser.add_argument("--batch_size",
                        type=int,
                        default=100)
    parser.add_argument("--tmp_dir",
                        default=tempfile.gettempdir())
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.mask_dir = pathlib.Path(args.mask_dir)
    args.tmp_dir = pathlib.Path(args.tmp_dir)
    assert args.input_dir.exists(), "Input directory does not exist!"
    assert args.mask_dir.exists(), "Mask directory does not exist!"
    assert args.tmp_dir.exists(), "Temporary directory does not exist!"
    with tempfile.TemporaryDirectory(dir=args.tmp_dir) as tmp_dir:
        tmp_dir = pathlib.Path(tmp_dir)
        root_dir = args.input_dir.parent
        cmd = f"{PYTHON_PATH} utils/select_random_batch_from_dirs.py --root_dir {root_dir} --dir_names {args.input_dir.name} {args.mask_dir.name} --output_dir {tmp_dir} --batch_size {args.batch_size}"
        subprocess.check_output(shlex.split(cmd))
        tmp_input_dir = tmp_dir.joinpath(args.input_dir.name)
        tmp_mask_dir = tmp_dir.joinpath(args.mask_dir.name)
        example_ids = list(map(get_real_stem, tmp_input_dir.glob("*.nii.gz")))
        for method in args.methods:
            if method != "msggan":
                method_args = {
                    "nifti_dir": str(tmp_input_dir),
                    "num_jobs": 1
                }
                cwd = pathlib.Path.cwd()
                prefix = "traditional_anonymization_methods/"
                if method == "deface":
                    method_args["tmp_dir"] = args.tmp_dir
                    cwd = cwd.joinpath("traditional_anonymization_methods")
                    prefix = ""
                elif method == "quickshear":
                    method_args["mask_dir"] = str(tmp_mask_dir)
                elif method == "face_mask":
                    convert_cmd = f"{PYTHON_PATH} conversion/convert_to_analyze.py --nifti_dir {tmp_input_dir}"
                    subprocess.call(shlex.split(convert_cmd))
                    method_args["analyze_dir"] = method_args["nifti_dir"].replace("NIFTI", "ANALYZE")
                    del method_args["nifti_dir"]
                method_args = " ".join([f"--{k} {v}" for k, v in method_args.items()])
                method_cmd = f"{PYTHON_PATH} {prefix}{method}.py {method_args}"
                start = perf_counter()
                subprocess.check_output(shlex.split(method_cmd), cwd=cwd)
                end = perf_counter()
                elapsed_time = end - start
                print(f"Elapsed time for {method}: {elapsed_time} seconds, avg = {elapsed_time/args.batch_size}")
if __name__ == "__main__":
    main()
