""" Milchenko et al. - MATLAB """
from argparse import ArgumentParser
import pathlib
import subprocess
import shlex
import numpy as np
import tempfile
import multiprocessing
import functools
import shutil
def orchestrate_docker(ids: np.ndarray, input_dir: pathlib.Path, output_dir: pathlib.Path):
    with tempfile.TemporaryDirectory() as fold_dir:
        fold_dir_path = pathlib.Path(fold_dir)
        for id in ids:
            input_fname = input_dir.joinpath(f"{id}.hdr")
            input_fold_fname = fold_dir_path.joinpath(input_fname.name)
            shutil.copyfile(src=input_fname, dst=input_fold_fname)
            input_fname = input_dir.joinpath(f"{id}.img")
            input_fold_fname = fold_dir_path.joinpath(input_fname.name)
            shutil.copyfile(src=input_fname, dst=input_fold_fname)
        subprocess.check_output(shlex.split(f"docker run --rm -ti -v {fold_dir_path.resolve()}:/mnt/input -v {output_dir.resolve()}:/mnt/output face_mask_image:latest /opt/face_mask_transfer.sh"))
def main():
    parser = ArgumentParser()
    parser.add_argument("--analyze_dir",
                        help="The directory containing the NifTi files",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    args = parser.parse_args()
    args.analyze_dir = pathlib.Path(args.analyze_dir)
    args.analyze_dir.exists(), "Input directory does not exist!"
    args.output_dir = args.analyze_dir.with_name(f"{args.analyze_dir.name}__face_mask__".replace("ANALYZE", "NIFTI"))
    args.output_dir.mkdir(exist_ok=True)
    scan_ids = [analyze_fname.stem for analyze_fname in args.analyze_dir.glob("*.hdr")]
    fold_ids = np.array_split(scan_ids, args.num_jobs)
    subprocess.call(shlex.split(f"docker build -t face_mask_image traditional_anonymization_methods"))
    func = functools.partial(orchestrate_docker,
                             input_dir=args.analyze_dir,
                             output_dir=args.output_dir)
    with multiprocessing.Pool(processes=args.num_jobs) as pool:
        pool.map(func, fold_ids)
if __name__ == "__main__":
    main()
