""" Segonne et al. , FreeSurfer  """
import os
from argparse import ArgumentParser
import pathlib
from joblib import delayed, Parallel
import subprocess
import shlex
from tqdm import tqdm
FREESURFER_HOME = pathlib.Path.home().joinpath("Build", "freesurfer")
MRI_WATERSHED_PATH = FREESURFER_HOME.joinpath("bin", "mri_watershed")
assert MRI_WATERSHED_PATH.exists(), "FreeSurfer not properly installed!"
os.environ['FREESURFER_HOME'] = str(FREESURFER_HOME)
def execute_watershed(input_fname: pathlib.Path, output_dir: pathlib.Path):
    output_fname = output_dir.joinpath(input_fname.name)
    if output_fname.exists():
        return
    try:
        subprocess.call(shlex.split(f"{MRI_WATERSHED_PATH} {input_fname} {output_fname}"),
                        stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
    except subprocess.CalledProcessError:
        print(f"Error with file {input_fname}", flush=True)
def main():
    parser = ArgumentParser()
    parser.add_argument("--nifti_dir",
                        help="Where the input NifTi files are located",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    args = parser.parse_args()
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    assert args.nifti_dir, "Input directory does not exist!"
    args.output_dir = args.nifti_dir.parent.joinpath(f"{args.nifti_dir.name}__mri_watershed__")
    args.output_dir.mkdir(exist_ok=True)
    input_fnames = [input_fname for input_fname in args.nifti_dir.glob("*.nii.gz")]
    Parallel(n_jobs=args.num_jobs)(delayed(execute_watershed)(input_fname=input_fname,
                                                              output_dir=args.output_dir) for input_fname in tqdm(input_fnames))
if __name__ == "__main__":
    main()
