import pathlib
from anonymization.prepare_dl_dataset import resize_to_target_size, pad_to_output_size
import nibabel as nib
from nibabel.orientations import ornt_transform, axcodes2ornt, inv_ornt_aff, apply_orientation, io_orientation, aff2axcodes
import numpy as np
def save_resized_nifti_to_tmp_dir(nifti_fname: pathlib.Path,
                                  resolution: int,
                                  tmp_dir: pathlib.Path):
    output_fname = tmp_dir.joinpath(nifti_fname.name)
    img = nib.load(nifti_fname)
    vox_array = img.get_fdata(dtype=np.float32)
    vox_array = pad_to_output_size(vox_array)
    vox_array = resize_to_target_size(arr=vox_array, tgt_size=(resolution,) * 3)
    new_ornt = axcodes2ornt(('R', 'A', 'S'))
    affine = img.affine
    orig_ornt = io_orientation(img.affine)
    ornt_trans = ornt_transform(orig_ornt, new_ornt)
    orig_shape = vox_array.shape
    new_vox_array = apply_orientation(vox_array, ornt_trans)
    aff_trans = inv_ornt_aff(ornt_trans, orig_shape)
    new_affine = np.dot(affine, aff_trans)
    new_img = nib.Nifti1Image(new_vox_array, new_affine, img.header)
    nib.save(new_img, output_fname)
    return output_fname
