import os
from argparse import ArgumentParser
import pathlib
import shutil
import subprocess
import shlex
from tqdm import tqdm
from joblib import Parallel, delayed
HOME_DIR = os.path.join(os.path.expanduser("~"))
os.environ["PATH"] += os.pathsep + os.pathsep.join([os.path.join(HOME_DIR, "Build/dpat-tools/LIBRARY/"),
                                                    os.path.join(HOME_DIR, "FSL/bin/")])
os.environ["FSLWISH"] = os.path.join(HOME_DIR, "FSL/bin/fslwish")
os.environ["FSLDIR"] = os.path.join(HOME_DIR, "FSL")
os.environ["FSLMACHINELIST"] = ""
os.environ["FSLTCLSH"] = os.path.join(HOME_DIR, "FSL/bin/fsltclsh")
os.environ["FSLREMOTECALL"] = ""
os.environ["FSLLOCKDIR"] = ""
os.environ["FSLGECUDAQ"] = "cuda.q"
os.environ["FSLOUTPUTTYPE"] = "NIFTI_GZ"
os.environ["FSLMULTIFILEQUIT"] = "TRUE"
def execute_fsl_fast(nifti_fname: pathlib.Path, output_dir: pathlib.Path):
    example_id = str(nifti_fname.name).split(".nii.gz")[0]
    seg_fname = nifti_fname.parent.joinpath(f"{example_id}_seg.nii.gz")
    subprocess.check_output(shlex.split(f"sienax {nifti_fname}"))
    output_fname = output_dir.joinpath(seg_fname.name)
    shutil.move(src=seg_fname, dst=output_fname)
def main():
    parser = ArgumentParser()
    parser.add_argument("--nifti_dir",
                        help="Where the NifTi files reside",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=10)
    args = parser.parse_args()
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    args.nifti_dir.exists(), "Input NifTi directory does not exist!"
    nifti_fnames = [nifti_fname for nifti_fname in args.nifti_dir.glob("*.nii.gz")]
    output_dir = args.nifti_dir.with_name(f"{args.nifti_dir.name}_FSL_FAST")
    output_dir.mkdir(exist_ok=True)
    Parallel(n_jobs=args.num_jobs)(delayed(execute_fsl_fast)(nifti_fname=nifti_fname,
                                                             output_dir=output_dir) for nifti_fname in tqdm(nifti_fnames))
if __name__ == "__main__":
    main()
