import os
from argparse import ArgumentParser
from typing import List
import pathlib
import tempfile
import shutil
import subprocess
import shlex
import random
from utils import get_real_stem
HOME_DIR = os.path.join(os.path.expanduser("~"))
os.environ["PATH"] += os.pathsep + os.pathsep.join([os.path.join(HOME_DIR, "Build/dpat-tools/LIBRARY/"),
                                                    os.path.join(HOME_DIR, "FSL/bin/")])
os.environ["FSLWISH"] = os.path.join(HOME_DIR, "FSL/bin/fslwish")
os.environ["FSLDIR"] = os.path.join(HOME_DIR, "FSL")
os.environ["FSLMACHINELIST"] = ""
os.environ["FSLTCLSH"] = os.path.join(HOME_DIR, "FSL/bin/fsltclsh")
os.environ["FSLREMOTECALL"] = ""
os.environ["FSLLOCKDIR"] = ""
os.environ["FSLGECUDAQ"] = "cuda.q"
os.environ["FSLOUTPUTTYPE"] = "NIFTI_GZ"
os.environ["FSLMULTIFILEQUIT"] = "TRUE"
def execute_mist(tmp_dir: pathlib.Path,
                 structures: List[str]):
    args = " ".join(structures)
    cmd = f"mist_1_train {args}"
    subprocess.call(shlex.split(cmd), cwd=tmp_dir)
def main():
    parser = ArgumentParser()
    parser.add_argument("--nifti_dir",
                        required=True)
    parser.add_argument("--indices_fname",
                        required=True)
    parser.add_argument("--num_training_samples",
                        help="How many training samples should be chosen [0 to take all]",
                        type=int,
                        default=100)
    parser.add_argument("--structures",
                        nargs="+",
                        default=["putamen", "pallidum", "caudate_accumbens", "thalamus"])
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    parser.add_argument("--tmp_dir",
                        default=tempfile.gettempdir())
    args = parser.parse_args()
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    args.indices_fname = pathlib.Path(args.indices_fname)
    args.nifti_dir.exists(), "Input directory does not exist!"
    args.indices_fname = pathlib.Path(args.indices_fname)
    assert args.num_training_samples >= 0
    ix = args.indices_fname.read_text().strip().split("\n")
    if args.num_training_samples > 0:
        ix = random.sample(ix, k=args.num_training_samples)
    args.nifti_fnames = list(args.nifti_dir.glob("*.nii.gz"))
    args.nifti_train_fnames = [nifti_fname for nifti_fname in args.nifti_fnames if get_real_stem(nifti_fname) in ix]
    with tempfile.TemporaryDirectory() as tmp_dir:
        tmp_dir = pathlib.Path(tmp_dir)
        subject_dirs = []
        for nifti_train_fname in args.nifti_train_fnames:
            subject_id = get_real_stem(nifti_train_fname)
            subject_dir = tmp_dir.joinpath(subject_id)
            subject_dir.mkdir()
            shutil.copyfile(src=nifti_train_fname, dst=subject_dir.joinpath("T1w.nii.gz"))
            subject_dirs.append(subject_dir)
        print("...")
        mist_subjects_fname = tmp_dir.joinpath("mist_subjects")
        with open(mist_subjects_fname, "w") as f:
            for subject_dir in subject_dirs:
                f.write(f"{subject_dir}\n")
        shutil.copy(src="traditional_downstream_tasks/mist_filenames", dst=tmp_dir)
        execute_mist(tmp_dir=tmp_dir,
                     structures=args.structures)
        shutil.move(src=tmp_dir.joinpath("mist_out"),
                    dst=args.nifti_dir.parent.joinpath(f"{args.nifti_dir.name}_FslMist_Model"))
if __name__ == "__main__":
    main()
