import os
from argparse import ArgumentParser
import pathlib
import shutil
import subprocess
import shlex
import re
from tempfile import gettempdir, TemporaryDirectory
from tqdm import tqdm
from joblib import Parallel, delayed
from utils import get_real_stem
import nibabel as nib
from traditional_downstream_tasks import save_resized_nifti_to_tmp_dir
from utils import get_real_stem
extract_volumes = re.compile(r"BRAIN\s*([0-9]*\.[0-9]*) ([0-9]*\.[0-9]*)")
HOME_DIR = os.path.join(os.path.expanduser("~"))
os.environ["PATH"] += os.pathsep + os.pathsep.join([os.path.join(HOME_DIR, "Build/dpat-tools/LIBRARY/"),
                                                    os.path.join(HOME_DIR, "FSL/bin/")])
os.environ["FSLWISH"] = os.path.join(HOME_DIR, "FSL/bin/fslwish")
os.environ["FSLDIR"] = os.path.join(HOME_DIR, "FSL")
os.environ["FSLMACHINELIST"] = ""
os.environ["FSLTCLSH"] = os.path.join(HOME_DIR, "FSL/bin/fsltclsh")
os.environ["FSLREMOTECALL"] = ""
os.environ["FSLLOCKDIR"] = ""
os.environ["FSLGECUDAQ"] = "cuda.q"
os.environ["FSLOUTPUTTYPE"] = "NIFTI_GZ"
os.environ["FSLMULTIFILEQUIT"] = "TRUE"
def execute_fsl_sienax(nifti_fname: pathlib.Path,
                       output_dir: pathlib.Path,
                       tmp_dir: pathlib.Path):
    if output_dir.joinpath(f"{get_real_stem(nifti_fname)}_sienax").exists():
        print("Exists already. Skipping..")
        return
    try:
        with TemporaryDirectory(dir=tmp_dir) as example_tmp_dir:
            example_tmp_dir = pathlib.Path(example_tmp_dir)
            nifti_tmp_fname = example_tmp_dir.joinpath(nifti_fname.name)
            shutil.copyfile(src=nifti_fname, dst=nifti_tmp_fname)
            example_id = get_real_stem(nifti_tmp_fname)
            sienax_dir = example_tmp_dir.joinpath(f"{example_id}_sienax")
            subprocess.check_output(shlex.split(f"sienax {nifti_tmp_fname} -r -d -B '-B'"))
            shutil.move(src=str(sienax_dir), dst=str(output_dir))
    except IndexError as e:
        print(f"Error with file {nifti_fname}")
def main():
    parser = ArgumentParser()
    parser.add_argument("--nifti_dir",
                        help="Where the NifTi files reside",
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=1)
    parser.add_argument("--index_fname",
                        help="Only run on indices from index file",
                        required=True)
    parser.add_argument("--tmp_dir",
                        help="Location of the temporary directory",
                        default=gettempdir())
    args = parser.parse_args()
    args.nifti_dir = pathlib.Path(args.nifti_dir)
    args.tmp_dir = pathlib.Path(args.tmp_dir)
    args.index_fname = pathlib.Path(args.index_fname)
    args.nifti_dir.exists(), "Input NifTi directory does not exist!"
    indices = args.index_fname.read_text().strip().split("\n")
    nifti_fnames = [nifti_fname for nifti_fname in args.nifti_dir.glob("*.nii.gz") if get_real_stem(nifti_fname) in indices]
    output_dir = args.nifti_dir.with_name(f"{args.nifti_dir.name}_FslSienax")
    output_dir.mkdir(exist_ok=True)
    Parallel(n_jobs=args.num_jobs)(delayed(execute_fsl_sienax)(nifti_fname=nifti_fname,
                                                               output_dir=output_dir,
                                                               tmp_dir=args.tmp_dir) for nifti_fname in tqdm(nifti_fnames))
if __name__ == "__main__":
    main()
