from argparse import ArgumentParser
import pathlib
import numpy as np
from skimage.io import imread, imsave
from skimage.filters import gaussian
from tqdm import tqdm
def main():
    parser = ArgumentParser()
    parser.add_argument("--renderings_dir",
                        help="The path where the renderings are located",
                        required=True)
    args = parser.parse_args()
    args.renderings_dir = pathlib.Path(args.renderings_dir)
    assert args.renderings_dir, "Renderings directory does not exist!"
    for subject_dir in tqdm(args.renderings_dir.iterdir()):
        if subject_dir.is_dir():
            original_fname = subject_dir.joinpath("original.png")
            arr = imread(original_fname)
            arr = gaussian(arr, sigma=5, multichannel=True)
            arr = (2**8 - 1) * arr
            arr = arr.astype(np.uint8)
            imsave(fname=original_fname.parent.joinpath("blurred.png"), arr=arr, check_contrast=False)
            imsave(fname=original_fname.parent.joinpath("black.png"), arr=np.zeros_like(arr), check_contrast=False)
if __name__ == "__main__":
    main()
