from argparse import ArgumentParser
import shutil
import pathlib
from functools import reduce
import itertools
import operator
import random
import string
import numpy as np
import pandas as pd
from tqdm import trange
from sklearn.utils import shuffle
from utils import get_real_stem
SERIAL_NUMBER_ALPHABET = string.ascii_lowercase + string.ascii_uppercase + string.digits
SERIAL_NUMBER_LENGTH = 32
def main():
    parser = ArgumentParser()
    parser.add_argument("--base_dir",
                        help="Where the originals are being stored",
                        required=True)
    parser.add_argument("--modalities",
                        nargs="+",
                        default=('quickshear', 'face_mask', 'mri_watershed', 'deface', 'cp-gan', 'blurred', 'original', 'black'))
    parser.add_argument("--num_images",
                        help="How many images to select (incl. original)",
                        type=int,
                        default=5)
    args = parser.parse_args()
    args.base_dir = pathlib.Path(args.base_dir)
    args.data_dirs = {modality: args.base_dir.parent.joinpath(args.base_dir.name + f"__{modality}__") for modality in args.modalities}
    args.output_dir = args.base_dir.parent.joinpath("user_study_nuevo")
    args.output_dir.mkdir(exist_ok=True)
    args.data_dirs['blurred'] = args.base_dir
    args.data_dirs['original'] = args.base_dir
    args.data_dirs['black'] = args.base_dir
    if args.output_dir.joinpath("regime.csv").exists():
        print("Output exists already!")
        return
    assert args.base_dir.exists(), "Base directory does not exist!"
    assert all(data_dir.exists() for data_dir in args.data_dirs.values()), "Not all data directories exist!"
    example_ids = [set(map(get_real_stem, data_dir.glob("*.nii.gz"))) for data_dir in args.data_dirs.values()]
    common_ids = list(reduce(operator.iand, example_ids))
    random.shuffle(common_ids)
    def _discard_element(l, v):
        return [x for x in l if x != v]
    num_modalities = len(args.modalities)
    anon_type = list(itertools.islice(itertools.cycle(args.modalities), len(common_ids) * num_modalities))
    original_id = list(itertools.chain.from_iterable(itertools.repeat(x, num_modalities) for x in common_ids))
    user_study = pd.DataFrame({'original_id': original_id, 'anon_type': anon_type})
    for col in range(args.num_images - 1):
        user_study[f"alternative_id_{col}"] = ''
    for i in trange(len(common_ids)):
        population = _discard_element(common_ids, common_ids[i])
        for j in range(num_modalities):
            alternative_ids = random.sample(population=population, k=args.num_images - 1)
            user_study.iloc[i * num_modalities + j, 2:] = alternative_ids
    user_study['original_pos'] = np.random.randint(args.num_images, size=len(user_study))
    user_study = shuffle(user_study).reset_index(drop=True)
    output_fname = args.output_dir.joinpath("regime.csv")
    user_study.to_csv(output_fname, index=False)
    output_fname.chmod(0o444)
if __name__ == "__main__":
    main()
