library(Rmisc)
library(dplyr)
library(readr)
library(rstudioapi)
library(tidyr)
library(stringr)
library(knitr)
library(forcats)
library(ggplot2)
library(extrafont)
library(magrittr)
library(purrr)
library(rsample)
library(knitr)
library(kableExtra)
base_size <- 30
theme_set(theme_light(base_size = base_size))
theme_update(text = element_text(size=base_size))
theme_update(axis.text.x = element_text(family = "TeX Gyre Pagella", angle = 45, vjust = 1.0, hjust=1, color = "black"),
             panel.grid.major.x = element_blank(),
             panel.border = element_blank(),
             strip.background=element_rect(fill="white"),
             strip.text = element_text(colour = 'black'),
             axis.ticks.y  = element_blank(),
             axis.ticks.x = element_line(color = "black"),
             panel.spacing.x=unit(0, "lines"))
canonical_order <- str_to_upper(c("blurred", "face mask", "deface", "quickshear", "mri watershed", "cp-gan"))
v <- seq_along(canonical_order)
names(v) <- canonical_order
oasis3.eval.version <- "2020-09-30T12:27:43.290347"
oasis3.eval.path <- str_c("/home/anonymized_user/Data/OASIS-3/user_study_nuevo/", "regime_", oasis3.eval.version, "_eval.csv")
adni.eval.version <- "2020-09-30T11:48:46.317722"
adni.eval.path <- str_c("/home/anonymized_user/Data/ADNI/user_study_nuevo/", "regime_", adni.eval.version, "_eval.csv")
data.oasis3 <- read_csv(oasis3.eval.path)
data.adni <- read_csv(adni.eval.path)
data <- bind_rows(list(`OASIS-3`=data.oasis3, `ADNI`=data.adni), .id = "dataset") %>%
  mutate(anon_type = str_replace(anon_type, "_", " ")) %>%
  mutate(dataset = factor(dataset),
         anon_type = factor(str_to_upper(anon_type), levels = canonical_order)) %>%
  mutate(worker_choice = if_else(worker_choice == -1, sample.int(n = 5, size = nrow(data.oasis3) + nrow(data.adni), replace = TRUE) - 1, worker_choice)) %>%
  mutate(isCorrect = worker_choice == correct_choice)
data %>%
  group_by(dataset, anon_type) %>%
  summarize(n_distinct(hit_id))
raw_data <- data %>%
  select(dataset, anon_type, isCorrect) %>%
  nest(-dataset, -anon_type) %>%
  mutate(IdentificationRate =  map(data, ~ bootstraps(., times = 1000) %$% map_dbl(splits, function(x) { 100 * mean(as_tibble(x)$isCorrect)}))) %>%
  select(-data) %>%
  unnest() %>%
  nest(-dataset, -anon_type) %>%
  mutate(IdentificationRateMean = map_dbl(data, ~ mean(.$IdentificationRate)),
         IdentificationRateSD = map_dbl(data, ~ sd(.$IdentificationRate))) %>%
  select(-data) %>%
  unnest() %>%
  mutate(IdentificationRate = str_c(round(IdentificationRateMean, digits = 2), "±", round(IdentificationRateSD, digits = 2))) %>%
  select(-IdentificationRateMean, -IdentificationRateSD) %>%
  pivot_wider(names_from = dataset, values_from = IdentificationRate,  names_glue = "{dataset}.{.value}") %>%
  rename(Method = anon_type)
header_row <- c("Method", 'OASIS-3', "ADNI")
latex_table <- raw_data %>%
  kable(format = "latex", booktabs = T, row.names = F, col.names = c(), linesep = "", align = c("l", rep("c", length(header_row) - 1))) %>%
  add_header_above(header_row, monospace = T) %>%
  column_spec(1, bold = T)
latex_table
gray.color <- "lightslategray"
plot <- data %>%
  select(dataset, anon_type, isCorrect) %>%
  nest(-dataset, -anon_type) %>%
  mutate(IdentificationRate =  map(data, ~ bootstraps(., times = 1000) %$% map_dbl(splits, function(x) { 100 * mean(as_tibble(x)$isCorrect)}))) %>%
  select(-data) %>%
  unnest(IdentificationRate) %>%
  ggplot(aes(x = anon_type, y = IdentificationRate, fill = anon_type)) +
  geom_boxplot(show.legend = FALSE, outlier.shape = NA, fatten = NULL, color = gray.color) +
  geom_boxplot(aes(color = anon_type),
               fatten = NULL, fill = NA, coef = 0, outlier.shape = NA, 
               show.legend = F) +
  stat_summary(geom = "crossbar", width=0.65, fatten=0, color=gray.color, show.legend = F, 
               fun.data = function(x){c(y=median(x), ymin=median(x), ymax=median(x))}) +
  facet_wrap(~dataset) +
  geom_hline(yintercept = 20, linetype = "dashed", size = 2, color = "darkgray") +
  geom_text(data = data.frame(anon_type = "FACE MASK",IdentificationRate = 21,
                              dataset = factor("ADNI",levels = c("ADNI", "OASIS-3"))), label = "Random Guessing", size = 20) +
  xlab(NULL) +
  ylab("Mean Identification Rate [%]")
plot
ggsave(filename = str_c("~/anonymized_userAuthoring/ICLR21/figs/experiments/user_study/appendix_bootstrap.png"), plot = plot, width = 28, height = 20, dpi = 300)
plot.ly <- bind_rows(list(`OASIS-3`=data.oasis3, `ADNI`=data.adni), .id = "dataset") %>%
  mutate(anon_type = str_replace(anon_type, "_", " ")) %>%
  mutate(dataset = factor(dataset),
         anon_type = factor(str_to_upper(anon_type), levels = canonical_order)) %>%
  group_by(dataset, anon_type) %>%
    summarize(UncertaintyRate = 100 * mean(worker_choice == -1)) %>%
  ggplot(aes(x = anon_type, y = UncertaintyRate)) +
  geom_col() +
  facet_wrap(~dataset) +
  xlab(NULL) +
  ylab("Uncertainty Rate [%]")
plot.ly
ggsave(filename = str_c("~/anonymized_userAuthoring/ICLR21/figs/experiments/user_study/appendix_uncertainty.png"), plot = plot.ly, width = 28, height = 20, dpi = 300)
