from argparse import ArgumentParser
import pathlib
from collections import ChainMap
import itertools
from operator import eq
import h5py
def get_members(fname):
    with h5py.File(fname, "r") as f:
        sub_keys = {kind: list(f[kind].keys()) for kind in f.keys()}
        return {fname.stem: sub_keys}
def has_relationship(lst, op):
    """ c.f. https://stackoverflow.com/a/4983308 """
    pairs = zip(lst, lst[1:])
    return all(itertools.starmap(op, pairs))
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        required=True)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    assert args.input_dir.exists()
    ids = dict(ChainMap(*[get_members(fname) for fname in args.input_dir.glob("*.h5")]))
    for modality in ("brain_mask", "original", "convex_hull"):
        file_lists = [sorted(val_dict[modality]) for val_dict in ids.values()]
        assert has_relationship(file_lists, eq)
if __name__ == "__main__":
    main()
