from argparse import ArgumentParser
import pathlib
from joblib import delayed, Parallel
import subprocess
import shlex
from tqdm import tqdm
from utils import save_lzma_ndarray
def archive_dir(input_dir: pathlib.Path, num_jobs: int):
    output_fname = input_dir.parent.joinpath(input_dir.name + ".xz")
    with open(output_fname, "w") as f:
        tar_process = subprocess.Popen(shlex.split(f"tar cf - {input_dir}"), stdout=subprocess.PIPE)
        pxz_process = subprocess.Popen(shlex.split(f"pxz -T {num_jobs}"), stdin=tar_process.stdout, stdout=f)
        pxz_process.communicate()
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        help="Where the NdArray files are located",
                        required=True)
    parser.add_argument("--mode",
                        help="Whether to convert single files to archive or the entire directory to an archive",
                        choices=("ARCHIVE_FILES", "ARCHIVE_DIR"),
                        required=True)
    parser.add_argument("--num_jobs",
                        type=int,
                        default=10)
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.input_dir.exists(), "Input directory does not exist!"
    print(f"Compressing with {args.num_jobs} threads..")
    if args.mode == "ARCHIVE_FILES":
        output_dir = args.input_dir.parent.joinpath(args.input_dir.name + "_LZMA")
        output_dir.mkdir(exist_ok=True)
        fnames = [fname for fname in args.input_dir.glob("*.npy")]
        Parallel(n_jobs=args.num_jobs)(delayed(save_lzma_ndarray)(fname=fname,
                                                                  output_dir=output_dir) for fname in tqdm(fnames))
    elif args.mode == "ARCHIVE_DIR":
        archive_dir(input_dir=args.input_dir, num_jobs=args.num_jobs)
    else:
        raise SystemError()
if __name__ == "__main__":
    main()
