import pathlib
import numpy as np
from argparse import ArgumentParser
from tqdm import tqdm
from skimage import io
def main():
    parser = ArgumentParser()
    parser.add_argument("--input_dir",
                        required=True)
    parser.add_argument("--output_dir",
                        required=True)
    parser.add_argument("--resolutions",
                        nargs="+",
                        type=int,
                        default=(16, 32, 64, 128))
    args = parser.parse_args()
    args.input_dir = pathlib.Path(args.input_dir)
    args.output_dir = pathlib.Path(args.output_dir)
    args.output_dir.mkdir(exist_ok=True)
    assert args.input_dir.exists(), "Input directory does not exist!"
    global_steps = sorted({int(input_fname.stem.split("_")[0]) for input_fname in args.input_dir.glob("*.png")})
    for global_step in tqdm(global_steps):
        collage = []
        for resolution in args.resolutions:
            img = io.imread(str(args.input_dir.joinpath(f"{global_step}_{resolution}.png")), as_gray=True)
            scale_factor = args.resolutions[-1] // resolution
            img_upscaled = np.kron(img, np.ones((scale_factor, scale_factor), img.dtype))
            collage.append(img_upscaled)
        collage = np.concatenate(collage, axis=0)
        output_fname = args.output_dir.joinpath(f"{global_step}.png")
        io.imsave(output_fname, collage)
if __name__ == "__main__":
    main()
